@@ -10,8 +10,12 @@ from neo.test.iotest.common_io_test import BaseTestIO
 
 class TestAsciiSpikeTrainIO(BaseTestIO, unittest.TestCase, ):
     ioclass = AsciiSpikeTrainIO
-    files_to_download = ['File_ascii_spiketrain_1.txt']
-    files_to_test = files_to_download
+    entities_to_download = [
+        'asciispiketrain'
+    ]
+    entities_to_test = [
+        'asciispiketrain/File_ascii_spiketrain_1.txt',
+    ]
 
 
 if __name__ == "__main__":
