@@ -17,9 +17,13 @@ from neo.test.iotest.common_io_test import BaseTestIO
 @unittest.skipUnless(HAVE_IGOR, "requires igor")
 class TestIgorIO(BaseTestIO, unittest.TestCase):
     ioclass = IgorIO
-    files_to_test = ['mac-version2.ibw',
-                     'win-version2.ibw']
-    files_to_download = files_to_test
+    entities_to_download = [
+        'igor'
+    ]
+    entities_to_test = [
+        'igor/mac-version2.ibw',
+        'igor/win-version2.ibw'
+    ]
 
 
 if __name__ == "__main__":
