@@ -5,17 +5,16 @@ Tests of neo.io.kwikio
 import unittest
 
 try:
-    import h5py
-
-    HAVE_H5PY = True
+    from klusta import kwik
+    HAVE_KWIK = True
 except ImportError:
-    HAVE_H5PY = False
+    HAVE_KWIK = False
+
 from neo.io import kwikio
 from neo.test.iotest.common_io_test import BaseTestIO
 
 
-@unittest.skipUnless(HAVE_H5PY, "requires h5py")
-@unittest.skipUnless(kwikio.HAVE_KWIK, "requires klusta")
+@unittest.skipUnless(HAVE_KWIK, "requires klusta")
 class TestKwikIO(BaseTestIO, unittest.TestCase):
     ioclass = kwikio.KwikIO
     entities_to_download = [
